@@ -9,6 +9,7 @@ describe 'watcher::policy' do
           :enforce_scope        => false,
           :enforce_new_defaults => false,
           :policy_path          => '/etc/watcher/policy.yaml',
+          :policy_default_rule  => 'default',
           :policy_dirs          => '/etc/watcher/policy.d',
           :policies             => {
             'context_is_admin' => {
@@ -32,12 +33,12 @@ describe 'watcher::policy' do
           :file_group   => 'watcher',
           :file_format  => 'yaml',
           :purge_config => false,
-          :tag          => 'watcher',
         )
         is_expected.to contain_oslo__policy('watcher_config').with(
           :enforce_scope        => false,
           :enforce_new_defaults => false,
           :policy_file          => '/etc/watcher/policy.yaml',
+          :policy_default_rule  => 'default',
           :policy_dirs          => '/etc/watcher/policy.d',
         )
       end
@@ -62,7 +63,6 @@ describe 'watcher::policy' do
           :file_group   => 'watcher',
           :file_format  => 'yaml',
           :purge_config => true,
-          :tag          => 'watcher',
         )
         is_expected.to contain_oslo__policy('watcher_config').with(
           :enforce_scope        => false,
