@@ -10,7 +10,7 @@ describe 'watcher::wsgi::apache' do
         :group                       => 'watcher',
         :path                        => '/',
         :priority                    => 10,
-        :servername                  => facts[:fqdn],
+        :servername                  => 'foo.example.com',
         :ssl                         => false,
         :threads                     => 1,
         :user                        => 'watcher',
@@ -145,14 +145,12 @@ describe 'watcher::wsgi::apache' do
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
-          :os_workers     => 42,
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld',
+          :os_workers => 42,
         }))
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :wsgi_script_path   => '/usr/lib/cgi-bin/watcher',
